@@ -65,6 +65,11 @@ def clean_recursive(obj):
 
 def save_cache(cache, experiment_id=''):
     with open(cache['log_dir'] + _os.sep + f"{experiment_id}_log.json", 'w') as fp:
-        log = _copy.deepcopy(cache)
-        clean_recursive(log)
-        _json.dump(log, fp)
+        try:
+            log = _copy.deepcopy(cache)
+            clean_recursive(log)
+            _json.dump(log, fp)
+        except Exception as e:
+            with open(cache['log_dir'] + _os.sep + f"{experiment_id}_log.txt", 'w') as raw:
+                raw.write(f"{e}\n")
+                raw.write(f"{cache}")
